.\" -*- nroff -*- generated from .Rd format
.BG
.FN krige.bayes
.TL
Bayesian Analysis for Gaussian Geostatistical Models
.DN
The function `krige.bayes' performs Bayesian analysis of
geostatistical data for different levels of uncertainty in the model
parameters.
.br
It returns results on the posterior distributions for the model
parameters and on the predictive distributions for prediction
locations (if provided).
.CS

krige.bayes(geodata, coords = geodata$coords, data = geodata$data,
            locations = "no",
     model = model.control(trend.d = "cte", trend.l = "cte",
                   cov.model = "exponential", kappa = 0.5,
                   aniso.pars = NULL, lambda = 1),
     prior = prior.control(beta.prior = c("flat", "normal",
                                          "fixed"),
                   beta = NULL, beta.var = NULL,
                   sill.prior = c("reciprocal", "fixed"),
                   sill = NULL,
                   range.prior = c("uniform", "exponential",
                                   "fixed", "squared.reciprocal",
                                   "reciprocal"),
                   exponential.prior.par = 1, range = NULL,
                   range.discrete = NULL,
                   nugget.prior = c("fixed", "uniform"),
                   nugget = 0, nugget.discrete = NULL),
     output = output.control(n.posterior = 1000,
                   n.predictive = NULL, moments = TRUE,
                   simulations.predictive = TRUE,
                   keep.simulations = TRUE, mean.estimator = TRUE,
                   quantile.estimator =  NULL,
                   probability.estimator = NULL,
                   signal = FALSE, messages.screen = TRUE))

.RA
.AG geodata
a list containing elements `coords' and
`data' as described next. Typically an object of the class
`"geodata"' - a geoR data-set. If not provided the arguments
`coords' and `data' must be provided instead.  
.AG coords
an n x 2 matrix where each row has the 2-D
coordinates of the n data locations.
By default it takes the
component `coords' of the argument `geodata', if provided.

.AG data
a vector with n data values. By default it takes the
component `data' of the argument `geodata', if provided.  
.AG locations
an N x 2 matrix or data-frame with the 2-D
coordinates of the N prediction locations.
Defaults to `"no"' in which case
the function returns only results on the posterior distributions of
the model parameters.  
.AG model
Defines model components. See section DETAILS below.  
.AG prior
Specification of priors for the model parameters. See
section DETAILS below.  
.AG output
Defines output options. See section DETAILS below.  
.RT
An object of the `class' `"krige.bayes"' which
is a list with the following components:
.IP "" 
.AG posterior
A list of results for the posterior distribution of the
model parameters. The components are:  
.AG beta.summary
summary of the posterior distribution
of the mean parameter beta.  
.AG sigmasq.summary
summary of the posterior distribution
of the variance parameter (partial sill) sigma^2.  
.AG phi.summary
summary of the posterior distribution
of the correlation parameter (range parameter) phi.  
.AG tausq.summary
summary of the posterior distribution
of the nugget variance parameter tau^2.  
.AG beta.samples
samples from the posterior distribution of the
mean parameter beta.  
.AG sigmasq.samples
samples from the posterior distribution
of the variance parameter (partial sill) sigma^2.  
.AG phi.samples
samples from the posterior distribution
of the correlation parameter (range parameter) phi.  
.AG tausq.samples
samples from the posterior distribution
of the nugget variance parameter tau^2.  
.AG phi.marginal
samples from the marginal posterior distribution
of the correlation parameterphi, resulting from
averaging the posterior  over the
distribution of (beta, sigma^2).  
.AG nugget.marginal
samples from the marginal posterior
distribution of the nugget variance parameter tau^2,
resulting from averaging the posterior over the
distribution of (beta, sigma^2).  
.AG predictive
A list of results for the predictive distribution of the
prediction locations (if provided). The
components are:
.AG moments
a numerical matrix. The columns are moments of the
predictive distribution at each prediction location
.AG simulations
a numerical matrix. Each column has a simulation drawn
from the predictive distribution. Returned
only if `keep.simulations = TRUE'.  
.AG mean.simulations
a vector with the mean at the prediction
locations computed by averaging over the simulations. Returned
only if `mean.estimator = TRUE'.  
.AG variance.simulations
a vector with the variance at the
prediction locations computed from the simulations. Returned
only if `mean.estimator = TRUE'. 
.AG quantile
A matrix or vector with quantile estimators. Returned
only if the argument `quantile.estimator' is used.  
.AG probability
A matrix or vector with probability estimators. Returned
only if the argument `probability.estimator' is used.  
.AG type.prediction
information on the type of prediction
performed.  
.AG message.prediction
information about the type of
inference, with or whitout allowing for parameter uncertainty,
which has been performed.  
.AG .Random.seed
system random seed before run the function. Allows reproduction of results. If
the system `\&.Random.seed' is set to this value and the function is run
again, it will produce exactly the same results.  
.AG call
the function call.  

.SH Auxiliary functions
The functions of type `krige.bayes.aux' and `control' are auxiliary functions called by `krige.bayes'.
.SH REFERENCES
The technical details about the  implementation of `krige.bayes' can be
found at:
.IP "" 
.br
.IP "" 
Ribeiro, P.J. Jr. and Diggle, P.J. (1999) Bayesian inference in
Gaussian model-based geostatistics. Tech. Report ST-99-08, Dept
Maths and Stats, Lancaster University.
Available at: 
<URL: http://www.maths.lancs.ac.uk/~ribeiro/publications.html>
.IP "" 
Further information about geoR/geoS can be found at:
.IP "" 
.br
<URL: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html>
.SA
`lines.krige.bayes',
`image.krige.bayes' and
`persp.krige.bayes' for graphical output.  
`krige.conv' and
`ksline' for conventional kriging methods.
.EX
# generating a simulated data-set
ex.data <- grf(50, cov.pars=c(10, .25))
#
# defining the prediction grid:
ex.grid <- as.matrix(expand.grid(seq(0,1,l=11), seq(0,1,l=11)))
#
# computing Bayesian posterior and predictive distributions  



ex.bayes <- krige.bayes(ex.data, loc=ex.grid, prior =
                 prior.control(range.discrete=seq(0, 2, l=51)))

#
# Ploting theoretical amd empirical variograms
plot(ex.data)
# adding lines with fitted variograms
lines(ex.bayes, max.dist=1.2)
lines(ex.bayes, max.dist=1.2, summ="median", lty=2)
lines(ex.bayes, max.dist=1.2, summ="mean", lwd=2, lty=2)
#
# Ploting prediction some results
par.mf <- par()$mfrow
par(mfrow=c(2,2))
image.krige.bayes(ex.bayes, loc=ex.grid, main="predicted values")
image.krige.bayes(ex.bayes, val="moments.variance",
                  loc=ex.grid, main="prediction variance")
image.krige.bayes(ex.bayes, val= "simulation", number.col=1,
                  loc=ex.grid,
      main="a simulation from the \\npredictive distribution")
image.krige.bayes(ex.bayes, val= "simulation", number.col=2,
                  loc=ex.grid,
     main="another simulation from \\nthe predictive distribution")
par(mfrow=par.mf)
.KW spatial, models
.WR
